==> nessie-model-0.19.0-sources.jar: org/projectnessie/model/Tag.java <==
/*
 * Copyright (C) 2020 Dremio
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.projectnessie.model;

import static org.projectnessie.model.Validation.validateReferenceName;

import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import javax.annotation.Nullable;
import org.eclipse.microprofile.openapi.annotations.enums.SchemaType;
import org.eclipse.microprofile.openapi.annotations.media.Schema;
import org.immutables.value.Value;

/** API representation of a Nessie Tag. This object is akin to a Ref in Git terminology. */
@Value.Immutable
@Schema(type = SchemaType.OBJECT, title = "Tag")
@JsonSerialize(as = ImmutableTag.class)
@JsonDeserialize(as = ImmutableTag.class)
@JsonTypeName("TAG")
public interface Tag extends Reference {

  @Override
  @Nullable
  String getHash();

  /**
   * Validation rule using {@link org.projectnessie.model.Validation#validateReferenceName(String)}.
   */
  @Value.Check
  default void checkName() {
    validateReferenceName(getName());
  }

  @Override
  default ReferenceType getType() {
    return ReferenceType.TAG;
  }

  static ImmutableTag.Builder builder() {
    return ImmutableTag.builder();
  }

  static Tag of(String name, String hash) {
    return builder().name(name).hash(hash).build();
  }
}

==> nessie-model-0.48.0-sources.jar: org/projectnessie/model/Tag.java <==
/*
 * Copyright (C) 2020 Dremio
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.projectnessie.model;

import static org.projectnessie.model.Validation.validateReferenceName;

import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import javax.annotation.Nullable;
import org.eclipse.microprofile.openapi.annotations.enums.SchemaType;
import org.eclipse.microprofile.openapi.annotations.media.Schema;
import org.immutables.value.Value;

/** API representation of a Nessie Tag. This object is akin to a Ref in Git terminology. */
@Value.Immutable
@Schema(type = SchemaType.OBJECT, title = "Tag")
@JsonSerialize(as = ImmutableTag.class)
@JsonDeserialize(as = ImmutableTag.class)
@JsonTypeName("TAG")
public interface Tag extends Reference {

  @Override
  @Value.Parameter(order = 1)
  String getName();

  @Nullable
  @Override
  @Value.Parameter(order = 3)
  ReferenceMetadata getMetadata();

  @Override
  @Nullable
  @Value.Parameter(order = 2)
  String getHash();

  /**
   * Validation rule using {@link org.projectnessie.model.Validation#validateReferenceName(String)}.
   */
  @Value.Check
  default void checkName() {
    validateReferenceName(getName());
  }

  @Override
  default ReferenceType getType() {
    return ReferenceType.TAG;
  }

  static ImmutableTag.Builder builder() {
    return ImmutableTag.builder();
  }

  static Tag of(String name, String hash) {
    return ImmutableTag.of(name, hash, null);
  }

  static Tag of(String name, String hash, ReferenceMetadata metadata) {
    return ImmutableTag.of(name, hash, metadata);
  }
}
